F1PacketCarSetups

Struct F1PacketCarSetups 

#[non_exhaustive]
pub struct F1PacketCarSetups { pub data: Vec<CarSetupData>, pub next_front_wing_value: f32, }
Car setups for all cars in the race. In multiplayer games, other player cars will appear as blank. You will only be able to see your car setup and AI cars.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
data: Vec<CarSetupData>

Setup data for all cars on track. Should have a size of 22.

next_front_wing_value: f32

Value of front wing after next pit stop - player only. Available from the 2024 format onwards