#[non_exhaustive]pub struct F1PacketLaps {
pub data: Vec<LapData>,
pub time_trial_pb_car_index: usize,
pub time_trial_rival_car_index: usize,
}Expand description
Data about all the lap times of cars in the session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data: Vec<LapData>Lap data for all cars on track. Should have a size of 22.
time_trial_pb_car_index: usizeIndex of personal best car in time trial mode (255 if invalid).
time_trial_rival_car_index: usizeIndex of rival’s car in time trial mode (255 if invalid).