#[non_exhaustive]pub struct F1PacketSessionHistory {
pub vehicle_index: usize,
pub num_laps: usize,
pub num_tyre_stints: usize,
pub best_lap_time_lap_num: usize,
pub best_sector1_lap_num: usize,
pub best_sector2_lap_num: usize,
pub best_sector3_lap_num: usize,
pub lap_history_data: Vec<LapHistoryData>,
pub tyre_stint_history_data: Vec<TyreStintHistoryData>,
}Expand description
Packet detailing lap and tyre data history for a given driver in the session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.vehicle_index: usizeIndex of the car this packet refers to.
num_laps: usizeNumber of laps in the data (including the current one).
num_tyre_stints: usizeNumber of tyre stints in the data (including the current one).
best_lap_time_lap_num: usizeNumber of the lap the best lap time was achieved on.
best_sector1_lap_num: usizeNumber of the lap the best sector 1 time was achieved on.
best_sector2_lap_num: usizeNumber of the lap the best sector 2 time was achieved on.
best_sector3_lap_num: usizeNumber of the lap the best sector 3 time was achieved on.
lap_history_data: Vec<LapHistoryData>Lap history. Should have a size equal to
num_laps.
tyre_stint_history_data: Vec<TyreStintHistoryData>Tyre stint history.
Should have a size equal to
num_tyre_stints.